%
%               FILE DESCRIBING THE GODDARD MODIS MONTHY MEAN CHLOROPHYLL DATA SET MO1DMM14

% FUNCTIONS -- REQUIRED
GetFunctionName = 'getrectg';
% FUNCTIONS -- OPTIONAL
Cat_m_File = 'ffcsquery';

% VARIABLES -- OPTIONAL
CatalogServer = 'http://acdisx.gsfc.nasa.gov/daac-bin/nph-dods/DODS/catalog/MO1DMM14-cat.dat';

Nlon = 360;
Nlat = 180;
axes_order = [2 1 0 0];

% VARIABLES -- REQUIRED
LonRange = [-180 180];
LatRange = [90 -90];
TimeRange = [2000+11*30/365 2002+2*30/365];
DepthRange = [0 0];
Resolution = 111.0;

DataName = 'Monthly Mean Chlorophyll M01DMM14 - GSFC';
SelectableVariables = str2mat('Chlorophyll');
DodsName = 'chlor_MODIS_mean';

Additional_FileServer_Constraints = 'type&type="cldfrc"';
% note: DataNull is applied *before* scaling
DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
DataNull(5) = {NaN};
DataScale = [NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             NaN NaN; ...
             -5 0.001];

Acknowledge = sprintf('%s\n', ...
[ '  ']);

% COMMENTS
Comments = sprintf('%s\n', ...
'      Monthly Mean Chlorophyll (in mg/m^3)', ...
' ', ...
'    MODIS Oceans 1 degree resolution (180 x 360) mapped Chlorophyll Concentration ',...
' product (monthly mean). Geographic projection in HDF-EOS format. ',...
' ',...
'    To obtain a more interesting plot, the user might want to set extreme positive and ',...
' negative values to nan as follows:',...
' ',...
'    chl = Rx_Chlorophyll; ',...
'    nn = find(chl>3); ',...
'    chl(nn) = nan; ',...
'    nn = find(chl<-1); ',...
'    chl(nn) = nan; ',...
'    figure(9);imagesc(Rx_Longitude,Rx_Latitude,chl);set(gca,''ydir'',''normal'');colorbar',...
' ',...
' For more information see:',...
 'http://daac.gsfc.nasa.gov/DATASET_DOCS/MODIS_ocean_L3_mapped1d_tga.html',...
' ',...
' or more generally:',...
'http://daac.gsfc.nasa.gov/MODIS/documentation/modis_tga_table_docs.shtml');



