%
%  Gulf of Maine Bathymetry

GetFunctionName = 'getrectg';
Server = 'http://stellwagen.er.usgs.gov/cgi-bin/nph-nc/data/gom/gom15.cdf';
Nlat = 1561;

LonRange = [-71.5 -63.0999];
LatRange = [45.9875 39.5041];
TimeRange = [1800.0 str2num(datestr(date,10))];
DepthRange = [0.0 0.0];
DepthUnits = '';
Resolution = 0.5;

% Force gridcat to ignore the axes popup window. 
axes_order = [2 1 0 0];

DataName = 'Bathymetry - Gulf of Maine - USGS';
SelectableVariables = str2mat('Bathymetry');
DodsName = str2mat('z');

DataNull = cell(size(DodsName,1)+4,1);
[DataNull(:)] = deal({nan}); 
[DataNull(5:length(DataNull))] = deal({-9999999790214767953607394487959552.0});

Acknowledge = sprintf('%s\n\n%s\n%s\n%s\n%s\n%s\n%s', ...
    [ 'The authors of this dataset are E. Roworth and R. Signell.  ', ...
      'The data were provided by U. S. Geological Survey. ', ...
      '(http://oracle.er.usgs.gov/GoMaine/bathy/index.htm) and accessed via ', ...
      'the Distributed Oceanographic Data System (DODS: ', ...
      'http://www.unidata.ucar.edu/packages/dods).'], ...
    [ 'Citation:  D.R. Lynch and C. R. Naimie, 1993, The M2 tide and its residual ',...
      'on the outer banks of the Gulf of Maine, Journal of Physical Oceanography,',...
      ' v. 23, n. 10, p. 2222-2253.'],...
    [ 'Richard J. Sandy, The Navy''s Bathymetric Databases... From the Sea, ',...
      'Sea Technology. Vol 37, No. 11 November 1996 P.53-56. '], ...
    [ 'W.H.F. Smith and P. Wessel, Gridding with Continuous curvature splines ',...
      'in tension, Geophysics. Vol 55, NO. 3 March 1990 P. 293-305.'],...
    [ 'Wessel, P., and W. H. F. Smith, New version of the Generic Mapping Tools ',...
      'released, EOS Trans. Amer. Geophys. U., vol. 76, pp. 329, 1995.'],...
    [ 'Wessel, P., and W. H. F. Smith, New version of the Generic Mapping Tools ',...
      'released, EOS Trans. Amer. Geophys. U. electronic supplement, ',...
      'http://www.agu.org/eos_elec95154e.html, 1995. '],...
    [ 'Wessel, P., and W. H. F. Smith, Free software helps map and display data, ',...
      'EOS Trans. Amer. Geophys. U., vol. 72, pp. 441, 445-446, 1991.']);

Comments1 = sprintf('%s\n', ...
'                              Gulf of Maine Bathymetry', ...
'     ', ...
'    This is a 15 arc second (~0.5 km) bathymetric grids for the Gulf of Maine (Lon = 71.5',...
'    - 66 W, Lat = 39.5 - 65N) compiled by Ed Roworth and Rich Signell from the following ',...
'    set of published and non-published data sets: ', ...
'    ', ...
'    NOAA Hydrographic Survey Data,',...
'    NGDC Marine Trackline Geophysics Data,', ...
'    Naval Oceanographic Office DBDB-V gridded bathymetry,', ...
'    Data from Bedford Institute of Oceanography, ',...
'    Data from Brookhaven National Laboratory,', ...
'    NOAA Medium resolution digital Shoreline and DMA World Vector Shoreline, ', ...
'    Defense Mapping Agency ETOPO5 Digital relief of the Surface of the Earth, ', ...
'    GEBCO General Bathymetric Chart of the Oceans, and ', ...
'    USGS North American 30 arc-second DEM.  ', ...
'    ', ...
'    Given the variety of input data, the specific characteristics of each dataset were ', ...
'    taken into account before incorporation into the composite dataset. These ',...
'    characteristics included the method of collection, survey resolution (sampling ', ...
'    frequency), method and units of navigational positioning, horizontal and vertical ',...
'    datum and tidal parameters used for corrections. ',...
'    ', ...
'    Bibliography',...
'    ', ...
'    Richard J. Sandy, The Navy''s Bathymetric Databases... From the Sea, Sea Technology. ',...
'    Vol 37, No. 11 November 1996 P.53-56. ', ...
'    ', ...
'    W.H.F. Smith and P. Wessel, Gridding with Continuous curvature splines in tension, ',...
'    Geophysics. Vol 55, NO. 3 March 1990 P. 293-305.',...
'    ', ...
'    Wessel, P., and W. H. F. Smith, New version of the Generic Mapping Tools released, ',...
'    EOS Trans. Amer. Geophys. U., vol. 76, pp. 329, 1995.',...
'    ', ...
'    Wessel, P., and W. H. F. Smith, New version of the Generic Mapping Tools released, ',...
'    EOS Trans. Amer. Geophys. U. electronic supplement, ',...
'    http://www.agu.org/eos_elec95154e.html, 1995. ',...
'    ', ...
'    Wessel, P., and W. H. F. Smith, Free software helps map and display data, EOS Trans. ',...
'    Amer. Geophys. U., vol. 72, pp. 441, 445-446, 1991.');

Comments2 = sprintf('%s\n', ...
'   ', ...
'    Spatial_Domain = ', ...
'         Bounding Coordinates: ', ...
'              West Bounding Coordinate:  71.4979 W ', ...
'              East Bounding Coordinate:  63.1020 W ', ...
'              South Bounding Coordinate: 39.5062 N ', ...
'              North Bounding Coordinate: 45.9854 N ', ...
'    Units:  km ', ...
'    Spatial Resolution: 0.4661 km', ...
'   ', ...
'    Point_of_Contact = ', ...
'         Address: ', ...
'               Rich Signell', ...
'               384 Woods Hole Road', ...
'               U.S. Geological Survey', ...
'               Woods Hole, MA 02543 ', ...
'               USA ', ...
'               Electronic Mail Address: INTERNET > rsignell@crusty.er.usgs.gov ', ...
'               Web Page URL: http://crusty.er.usgs.gov/rsignell.html ', ...
'         Address - dods: ',...
'               Electronic Mail Address: INTERNET > support@unidata.ucar.edu ');

Comments = [Comments1 Comments2];

%
% $Log: gomtopo.m,v $
% Revision 1.7  2002/08/14 02:16:50  dan
% Added axes_order so that axes popup does not popup.
%
% Revision 1.6  2002/06/23 20:07:22  dan
% USGS changed the location of this file; need a new base URL.
%
% Revision 1.5  2002/05/07 16:45:15  dan
% Base URL changed at USGS.
%
% Revision 1.4  2002/04/08 21:36:59  dan
% Fixed end time.
%
% Revision 1.3  2002/01/23 06:37:28  dbyrne
%
%
% Changed to fix upside-down latitude map. -- dbyrne 2002/01/22
%
% Revision 1.2  2001/01/18 19:35:44  dbyrne
%
%
% datarange is no longer in use.  changed datanull to cell in many cases.
% -- dbyrne 01/01/17
%
% Revision 1.1  2000/05/31 23:12:55  dbyrne
% *** empty log message ***
%
% Revision 1.1  2000/05/31 22:59:20  root
% *** empty log message ***
%
% Revision 1.5  2000/05/24 21:54:44  root
% Fixed very bad data ranges. -- dbyrne 00/05/25
%
% Revision 1.4  2000/03/28 20:23:46  root
% Updates from release gui-3-2-0
%
% Revision 1.7  1999/11/23 19:43:01  kwoklin
% Add tbase data set.  Use recturl for simple getrectg geturl file. klee
%
% Revision 1.6  1999/07/19 20:57:06  kwoklin
% *** empty log message ***
%
% Revision 1.4  1999/06/01 00:53:51  dbyrne
%
%
% Many fixes in prep for AGU.  fth, htn, glk and prevu changed to use
% fileservers. -- dbyrne 99/05/31
%
% Revision 1.2  1999/05/28 17:32:51  kwoklin
% Add all globec datasets. Fix depth representation for all globec datasets
% and nbneer dataset. Fix frontal display for htn and glkfront. Make use of
% getjgsta for all jgofs datasets. Point usgsmbay to new server. Point htn,
% glk, fth and prevu to new FF server.                                 klee
%

% $Id: gomtopo.m,v 1.7 2002/08/14 02:16:50 dan Exp $
% klee 12/98

